@@ -1,7 +1,8 @@
+#' @export
 `fitted.Arima` <-
 function (object,...) 
 {
-fitted=eval(object$call$x)-residuals(object)
+fitted=eval(object$call$x)-object$residuals
 fitted
 }
 
